from PySide2 import QtWidgets, QtGui

JSON = """{
    "autoretry_policy": {
        "failed": {
            "max_retries": 1
        }, 
        "preempted": {
            "max_retries": 1
        }
    }, 
    "environment": {
        "ADSKFLEX_LICENSE_FILE": "@conductor_adlm", 
        "ARNOLD_PLUGIN_PATH": "/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./plug-ins:/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./shaders", 
        "AUTODESK_ADLM_THINCLIENT_ENV": "/opt/autodesk/max-io/2019/max-io2019.SP0/Conductor/AdlmThinClientCustomEnv.xml", 
        "LD_LIBRARY_PATH": "/opt/autodesk/max-io/2019/max-io2019.SP0/lib:/opt/autodesk/max-io/2019/max-io2019.SP0/plug-ins/xgen/lib:/opt/autodesk/max-io/2019/max-io2019.SP0/plug-ins/bifrost/lib", 
        "MAX_DEBUG_ENABLE_CRASH_REPORTING": "0", 
        "MAX_DEBUG_SIGTERM_AS_SIGINT": "1", 
        "MAX_DISABLE_CER": "1", 
        "MAX_DISABLE_CLIC_IPM": "1", 
        "MAX_LICENSE": "unlimited", 
        "MAX_LICENSE_METHOD": "network", 
        "MAX_LOCATION": "/opt/autodesk/max-io/2019/max-io2019.SP0", 
        "MAX_PLUG_IN_PATH": "/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./plug-ins", 
        "MAX_RENDER_DESC_PATH": "/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2.", 
        "MAX_SCRIPT_PATH": "/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./scripts", 
        "PATH": "/opt/autodesk/max-io/2019/max-io2019.SP0/bin:/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./bin", 
        "PYTHONPATH": "/opt/autodesk/max-io/2019/max-io2019.SP0/Conductor:/opt/solidangle/arnold-max/3/arnold-max-max2019-3.1.2-2./scripts", 
        "solidangle_LICENSE": "4101@docker_host"
    }, 
    "instance_type": "n1-standard-1", 
    "job_title": "Max: - quack.0003 renderSetupLayer1", 
    "local_upload": false, 
    "location": "london", 
    "metadata": {
        "ConductorVersion": "0.1.42"
    }, 
    "notify": [], 
    "output_path": "/Volumes/xtr/gd/duck/images", 
    "preemptible": true, 
    "project": "ATestForScott", 
    "scout_frames": "1,11,21,31,41,51,61,71,81,91", 
    "software_package_ids": [
        "732e688c522899625db1627adaa7cf3e", 
        "8e87ae3ee8c721aad91f8a9e9c25db7e"
    ], 
    "tasks_data": [
        {
            "command": "3dsrender -r  -s 1 -e 1 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "1"
        }, 
        {
            "command": "3dsrender -r  -s 2 -e 2 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "2"
        }, 
        {
            "command": "3dsrender -r  -s 3 -e 3 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "3"
        }, 
        {
            "command": "3dsrender -r  -s 4 -e 4 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "4"
        }, 
        {
            "command": "3dsrender -r  -s 5 -e 5 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "5"
        }, 
        {
            "command": "3dsrender -r  -s 6 -e 6 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "6"
        }, 
        {
            "command": "3dsrender -r  -s 7 -e 7 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "7"
        }, 
        {
            "command": "3dsrender -r  -s 8 -e 8 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "8"
        }, 
        {
            "command": "3dsrender -r  -s 9 -e 9 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "9"
        }, 
        {
            "command": "3dsrender -r  -s 10 -e 10 -b 1 -rl renderSetupLayer1 -rd /Volumes/xtr/gd/duck/images  -proj /Volumes/xtr/gd/duck /Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
            "frames": "10"
        }
    ], 
    "upload_only": false, 
    "upload_paths": [
        "/Volumes/xtr/gd/duck/scenes/cone.ma", 
        "/Volumes/xtr/gd/duck/scenes/quack.0003.ma", 
        "/Volumes/xtr/gd/duck/sourceimages/alcazar.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0001.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0002.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0003.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0004.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0005.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0006.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0007.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0008.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0009.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bugs_seq/bugs.0010.jpg", 
        "/Volumes/xtr/gd/duck/sourceimages/bush_restaurant_4k.hdr", 
        "/Volumes/xtr/gd/duck/sourceimages/bush_restaurant_4k.tx"
    ]
}
"""


class PreviewTab(QtWidgets.QScrollArea):

    def __init__(self,dialog):
        super(PreviewTab, self).__init__()
    
        widget = QtWidgets.QWidget()
        self.dialog = dialog
        self.setWidget(widget)
        self.setWidgetResizable(1)

        layout = QtWidgets.QHBoxLayout()
        widget.setLayout(layout)

        self.text_area = QtWidgets.QTextEdit()

        self.text_area.setReadOnly(True)
        self.text_area.setWordWrapMode(QtGui.QTextOption.NoWrap)
        layout.addWidget(self.text_area)

        self.populate(JSON)

    def populate(self, json):
        self.text_area.setText(json)



import sys
import os

from PySide2 import QtWidgets, QtCore, QtGui
from ciocore.expander import Expander

from ciomax.collapsible_section import CollapsibleSection

from ciomax.general_section import GeneralSection
from ciomax.software_section import SoftwareSection
from ciomax.frames_section import FramesSection
from ciomax.info_section import InfoSection
from ciomax.environment_section import EnvironmentSection
from ciomax.metadata_section import MetadataSection
from ciomax.extra_assets_section import ExtraAssetsSection
from ciomax.advanced_section import AdvancedSection
from ciocore import data as coredata
# from ciomax.store import ConductorStore

from ciocore.gpath import Path

FIXTURES_DIR = os.path.expanduser(os.path.join("~", "Conductor", "fixtures"))


class MainTab(QtWidgets.QScrollArea):
    """
    Build the tab that contains the main configuration sections.
    """

    def __init__(self, dialog):
        super(MainTab, self).__init__()

        self.dialog = dialog
        coredata.init(product="maya-io")
        coredata.set_fixtures_dir(FIXTURES_DIR)
        coredata.data()

        widget = QtWidgets.QWidget()
        self.setWidget(widget)
        self.setWidgetResizable(1)

        sections_layout = QtWidgets.QVBoxLayout()
        widget.setLayout(sections_layout)

        self._section_classes = sorted(
            CollapsibleSection.__subclasses__(), key=lambda x: x.ORDER)
        self.sections = [cls(self.dialog) for cls in self._section_classes]

        for section in self.sections:
            sections_layout.addWidget(section)

        sections_layout.addStretch()

    def populate_from_store(self):
        for section in self.sections:
            section.populate_from_store()

    def section(self, classname):
        """
        Convenience to find sections by name.

        Makes it easier to allow sections to talk to each other.
        Example: Calculate info from stuff in the frames section
            self.section("InfoSection").calculate(self.section("FramesSection"))

        """

        return next(s for s in self.sections if s.__class__.__name__ == classname)

    def resolve(self, **kwargs):
        submission = {}
        context = self.get_context()
        expander = Expander(safe=True, **context)
        for section in self.sections:
            submission.update(section.resolve(expander, **kwargs))
        return submission

    def get_context(self):
        scenefile = "/get/doc/name.3ds"
        if scenefile:
            scenefile = Path(scenefile).posix_path(with_drive=False)
        scenedir = os.path.dirname(scenefile)
        scenenamex, ext = os.path.splitext(os.path.basename(scenefile))

        result = {
            "scenefile": scenefile,
            "scenedir": scenedir,
            "scenenamex": scenenamex,
            "ext": ext
        }
        return result




from ciomax import store
reload(store)

from ciomax import collapsible_section
reload(collapsible_section)

from ciomax.components import widgets
reload(widgets)

from ciomax.components import text_field_grp
reload(text_field_grp)

from ciomax.components import int_field_grp
reload(int_field_grp)

from ciomax.components import text_grp
reload(text_grp)

from ciomax.components import key_value_grp
reload(key_value_grp)

from ciomax.components import combo_box_grp
reload(combo_box_grp)

from ciomax.components import software_combo_box_grp
reload(software_combo_box_grp)

from ciomax.components import checkbox_grp
reload(checkbox_grp)

from ciomax import general_section
reload(general_section)

from ciomax import software_section
reload(software_section)

from ciomax import frames_section
reload(frames_section)

from ciomax import info_section
reload(info_section)

from ciomax import advanced_section
reload(advanced_section)

from ciomax import environment_section
reload(environment_section)

from ciomax import metadata_section
reload(metadata_section)

from ciomax import extra_assets_section
reload(extra_assets_section)

from ciomax import main_tab
reload(main_tab)

from ciomax import preview_tab
reload(preview_tab)



from PySide2 import QtWidgets, QtGui, QtCore

from ciomax.collapsible_section import CollapsibleSection
from ciomax.components.key_value_grp import KeyValueGrpList


class EnvironmentSection(CollapsibleSection):
    ORDER = 60

    def __init__(self, dialog):
        super(EnvironmentSection, self).__init__(dialog, "Extra Environment")

        self.component = KeyValueGrpList(
            checkbox_label="Excl", key_label="Name")
        self.content_layout.addWidget(self.component)
        self.configure_signals()

    def configure_signals(self):
        """Write to store when values change"""
        self.component.edited.connect(self.on_edited)

    def on_edited(self):
        self.dialog.store.set_extra_environment(list(self.component))

    def populate_from_store(self):
        store = self.dialog.store
        self.component.set_entries(store.extra_environment())

    # def resolve(self, expander):
    #     inst_type_desc = self.instance_type_component.combobox_machine.currentText()
    #     return {
    #         "job_title": expander.evaluate(self.title_component.field.text()),
    #         "output_path": self.destination_component.field.text(),
    #         "project": self.project_component.combobox.currentText(),
    #         "instance_type": inst_type_desc,
    #         "preemptible": self.instance_type_component.checkbox.isChecked()
    #     }
